pub struct HookRunResult {
pub output: HookOutput,
}Expand description
Aggregate result of executing one or more hooks in sequence.
Callers that do not need the output can ignore this and check only for Err.
Fields
output: HookOutputMerged output from the hook sequence. When multiple hooks emit
updatedToolOutput, the last non-None value wins.