Functions
- ensure_
memory_ dir - Ensure the memory directory exists, creating it if necessary.
- escape_
memory_ content - Escape
<agent-memory>and</agent-memory>tags from memory content. - load_
memory_ content - Reads
MEMORY.mdfrom the given directory and returns the first 200 lines. - resolve_
memory_ dir - Resolve the memory directory path for a given scope and agent name.